---
# Is this the primary user of the site?
superuser: true

social:
- icon: github
  icon_pack: fab
  link: https://github.com/lucmos/powermanim
  # label: GitHub Project Page
  display:
    header: true
---
